<?php
/**
 * Custom functions that act independently of the theme templates.
 *
 * Eventually, some of the functionality here could be replaced by core features.
 *
 * @package Raiden
 */

/**
 * Adds custom classes to the array of body classes.
 *
 * @param array $classes Classes for the body element.
 * @return array
 */
function raiden_body_classes( $classes ) {
	// Adds a class of group-blog to blogs with more than 1 published author.
	if ( is_multi_author() ) {
		$classes[] = 'group-blog';
	}

	// Site Layout.
	$layout = get_theme_mod( 'site_layout', 'layout-one' );
	if ( ! empty( $layout ) ) {
		$classes[] = esc_attr( $layout );
	}

	// Color scheme class.
	$scheme = get_theme_mod( 'color_scheme', 'default' );
	if ( $scheme ) {
		$classes[] = 'color-scheme-' . esc_attr( $scheme );
	}

	// Adds a class of hfeed to non-singular pages.
	if ( ! is_singular() ) {
		$classes[] = 'hfeed';
	}

	return $classes;
}
add_filter( 'body_class', 'raiden_body_classes' );
